hyperphor.multitool.browser


->url-paramscljs

(->url-params param-map)

Convert param map to string suitable for inclusion in URL

Convert param map to string suitable for inclusion in URL
raw docstring

browser-pathcljs

(browser-path)

Get the pathname as a sequence of components

Get the pathname as a sequence of components
raw docstring

browser-pathnamecljs

(browser-pathname)

Get the pathname (URL after host)

Get the pathname (URL after host)
raw docstring

browser-urlcljs

(browser-url)

Get URL of current page

Get URL of current page
raw docstring

copy-to-clipboardcljs

(copy-to-clipboard id)

Copy contents of HTML element into clipboard. Kludgey.

Copy contents of HTML element into clipboard. Kludgey.
raw docstring

hostcljs

(host)

Get hostname of currnet URL

Get hostname of currnet URL
raw docstring

open-in-browser-tabcljs

(open-in-browser-tab url name)

url-paramscljs

(url-params)

Get the url params from the browser window as a map

Get the url params from the browser window as a map
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries