hyperphor.multitool.cljcore

Java-only stuff

Java-only stuff
raw docstring

base64-decodeclj

(base64-decode b64-string)

base64-encodeclj

(base64-encode string)

cdclj

(cd dirname)

As in Unix shell cd

As in Unix shell cd
raw docstring

content-filesclj

(content-files dir & regex)

copy-pathsclj

(copy-paths in-path out-path)

Copy in-path to out-path, in-path can be URI or filename, out-path should be a file

Copy in-path to out-path, in-path can be URI or filename, out-path should be a file
raw docstring

dataset-fieldsclj

(dataset-fields ds)

date+clj

(date+ date days hours minutes)

date-formatclj

(date-format date format)

date-formatterclj


directory-filesclj

(directory-files d filterfn)

downloadclj

(download uri file)

Common use case for copy-paths

Common use case for copy-paths
raw docstring

ensure-directoryclj

(ensure-directory d)

Create directory if it doesn't exist (recursively)

Create directory if it doesn't exist (recursively)
raw docstring

ensure-fileclj

(ensure-file f)

Ensure that the directory structure to contain this file exists

Ensure that the directory structure to contain this file exists
raw docstring

errorclj

(error s & args)

Throw a generic Exception with formatted string

Throw a generic Exception with formatted string
raw docstring

error-messageclj

(error-message e)

Given an exception, returns the error message

Given an exception, returns the error message
raw docstring

expand-homedirclj

(expand-homedir path)

file-delete-recursivelyclj

(file-delete-recursively fname)

Delete a directory and its contents

Delete a directory and its contents
raw docstring

file-delete-safeclj

(file-delete-safe fname)

Delete a file or directory safely (that is, no error if doesn't exist)

Delete a file or directory safely (that is, no error if doesn't exist)
raw docstring

file-exists?clj

(file-exists? path)

True if file path exists

True if file `path` exists
raw docstring

file-linesclj

(file-lines file)

file-lines-outclj

(file-lines-out file seq)

file-seq-filteredclj

(file-seq-filtered remove-fn dir)

A tree seq on java.io.Files

A tree seq on java.io.Files
raw docstring

flatten-directoryclj

(flatten-directory dir dest-dir)

git-log-infoclj

(git-log-info file)

returns [user email timestamp msg commit] of last commit for file

returns [user email timestamp msg commit] of last commit for file
raw docstring

humanize-numberclj

(humanize-number n)

in-backgroundcljmacro

(in-background & body)

invoke-privateclj

(invoke-private o methodname)

java-resource->stringclj

(java-resource->string resource)

join-pathclj

(join-path & args)

Joins the elements passed in into a path

Joins the elements passed in into a path
raw docstring

list-dir-recursiveclj

(list-dir-recursive dir)

Like fs/list-dir, but recurses through subdirectories and does not include dirs in result. Ignore .dotfiles

Like fs/list-dir, but recurses through subdirectories and does not include dirs in result. Ignore .dotfiles
raw docstring

local-fileclj

(local-file url)
(local-file url local-file)

Make a copy of contens of url in a local temp file or supplied filename

Make a copy of contens of url in a local temp file or supplied filename
raw docstring

nowclj

(now)

open-urlclj

(open-url url)

parse-boolean-or-nilclj

(parse-boolean-or-nil value)

parse-long-or-nilclj

(parse-long-or-nil value)

pdoseqcljmacro

(pdoseq seqs & body)

Like doseq but each iteration gets its own thread.

Like doseq but each iteration gets its own thread.
raw docstring

pdoseq*cljmacro

(pdoseq* seqs & body)

Like doseq* but each iteration gets its own thread.

Like doseq* but each iteration gets its own thread.
raw docstring

pmap-keysclj

(pmap-keys f hashmap)

Map f over the kes of hashmap in parallel

Map f over the kes of hashmap in parallel
raw docstring

pmap-valuesclj

(pmap-values f hashmap)

Map f over the values of hashmap in parallel

Map f over the values of hashmap in parallel
raw docstring

process-file-linesclj

(process-file-lines f in out)

processorsclj

(processors)

Return the number of available processors

Return the number of available processors
raw docstring

read-charsclj

(read-chars reader n)

read-csv-mapsclj

(read-csv-maps f)

Read a csv file into maps

Read a csv file into maps
raw docstring

read-csv-rowsclj

(read-csv-rows f)

Read a csv file into vectors

Read a csv file into vectors
raw docstring

read-from-fileclj

(read-from-file file)

Read a form from a file

Read a form from a file
raw docstring

read-tsv-mapsclj

(read-tsv-maps f & [separator])

Given a tsv file with a header line, returns seq where each elt is a map of field names to strings

Given a tsv file with a header line, returns seq where each elt is a map of field names to strings
raw docstring

read-tsv-rowsclj

(read-tsv-rows f & [separator])

Read a tsv file into vectors

Read a tsv file into vectors
raw docstring

readerclj

(reader file)

Return a reader for a file, with homedir expansin

Return a reader for a file, with homedir expansin
raw docstring

schpitclj

(schpit f content & options)

Like core/spit, but will do something sensible for lazy seqs.

Like core/spit, but will do something sensible for lazy seqs.
raw docstring

schppitclj

(schppit f content & options)

Like schpit but will prettyprint.

Like schpit but will prettyprint.
raw docstring

sh-errcheckedclj

(sh-errchecked & args)

sh-strclj

(sh-str s)

Version of sh that takes a single string, which can include pipe operators etc. Also turns errors into exceptions

Version of sh that takes a single string, which can include pipe operators etc. Also turns errors into exceptions
raw docstring

sh-templateclj

(sh-template template params)

Version of sh uses templating

Version of sh uses templating
raw docstring

sleepclj

(sleep n)

split-pathclj

(split-path path)

Splits a path delimited with /

Splits a path delimited with /
raw docstring

start-periodic-process!clj

(start-periodic-process! t f)

Start a background process to execute thunk f every t mssc

Start a background process to execute thunk f every t mssc
raw docstring

string-search-allclj

(string-search-all string sub & [start])

Return a sequence of all positions where sub is found in string

Return a sequence of all positions where sub is found in string
raw docstring

substitute-file-linesclj

(substitute-file-lines map)

temp-dir-pathclj

(temp-dir-path)

temp-fileclj

(temp-file)

temp-file-pathclj

(temp-file-path)

timing-fnclj

(timing-fn f)

Returns a fn that acts like f, but return value is (time result), time in msec]

Returns a fn that acts like f, but return value is (time result), time in msec]
raw docstring

warnclj

(warn s & args)

wdclj

(wd)

As in Unix shell pwd

As in Unix shell pwd
raw docstring

write-csv-mapsclj

(write-csv-maps f rows)

write-csv-rowsclj

(write-csv-rows f rows)

write-tsv-mapsclj

(write-tsv-maps f rows & {:keys [separator cols] :or {separator \tab}})

write-tsv-rowsclj

(write-tsv-rows f rows & [separator])

writerclj

(writer file)

Return a writer for a file, with homedir expansin

Return a writer for a file, with homedir expansin
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries