(group-by* [key1 & key*] mapseq)Multilevel group-by
Multilevel group-by
(ms-filter ms field pred)Filter ms based on field and pred
Filter ms based on field and pred
(ms-find ms re)Find values that match re, return seq of [k v rec]
Find values that match re, return seq of [k v rec]
(ms-range field ms)Returns [min, max, count-distinct] using generic comapre
Returns [min, max, count-distinct] using generic comapre
(reshape-fat mapseq id-col prop-col val-col)Reshape a mapseq from skinny to fat
Reshape a mapseq from skinny to fat
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |