hyperphor.multitool.math


*Tclj/s


+Tclj/s


-Tclj/s


absTclj/s


coefficent-of-variationclj/s

(coefficent-of-variation seq)

Return coefficent of variation of the elements of seq

Return coefficent of variation of the elements of `seq`
raw docstring

covarianceclj/s

(covariance seq1 seq2)

Return the covariance between seq1 and seq2, which should be of equal size

Return the covariance between seq1 and seq2, which should be of equal size
raw docstring

d2rclj/s

(d2r d)

Convert degrees to radians

Convert degrees to radians
raw docstring

diffTclj/s


divides?clj/s

(divides? a b)

divisorsclj/s

(divisors n)

divTclj/s


divxTclj/s


euclidean-distanceclj/s

(euclidean-distance p0 p1)
(euclidean-distance x0 y0 x1 y1)

Euclidean distance between points. Either 2D points supplied as separate arguments, or between 2 n-dimensional points with vector coordinates

Euclidean distance between points. Either 2D points supplied as separate arguments, or between 2 n-dimensional points with vector coordinates
raw docstring

extrapolateclj/s

(extrapolate v)

Extrapolate a vector of numbers by one element, using method of finite differences

Extrapolate a vector of numbers by one element, using method of finite differences
raw docstring

factorialsclj/s


factorsclj/s

(factors n)

geometric-meanclj/s

(geometric-mean seq)

Return the geometric mean of the elements of seq

Return the geometric mean of the elements of `seq`
raw docstring

ilesclj/s

(iles seq n)

Return the boundaries of deciles (n-iles) of seq

Return the boundaries of deciles (n-iles) of seq
raw docstring

interpolateclj/s

(interpolate a b s)

Return a number between a and b, s is in interval [0, 1]

Return a number between a and b, s is in interval [0, 1]
raw docstring

interpolatedclj/s

(interpolated a b n)

Return a sequence of n equally-spaced numbers between a and b

Return a sequence of n equally-spaced numbers between a and b
raw docstring

interpolateTclj/s


manhattan-distanceclj/s

(manhattan-distance p0 p1)
(manhattan-distance x0 y0 x1 y1)

Manhattan distance between points. Either 2D points supplied as separate arguments, or between 2 n-dimensional points with vector coordinates

Manhattan distance between points. Either 2D points supplied as separate arguments, or between 2 n-dimensional points with vector coordinates
raw docstring

meanclj/s

(mean seq)

Return the arithmetic mean of the elements of seq

Return the arithmetic mean of the elements of `seq`
raw docstring

medianclj/s

(median seq)

Return the median of the elements of seq

Return the median of the elements of `seq`
raw docstring

outliers-byclj/s

(outliers-by scorefn seq factor)

Return elements of seq on whom scorefn is more than factor standard-deviations away from the mean.

Return elements of `seq` on whom `scorefn` is more than `factor` standard-deviations away from the mean.
raw docstring

pearson-correlation-coefficientclj/s

(pearson-correlation-coefficient seq1 seq2)

Return the correlation coefficient between seq1 and seq2, which should be of equal size. Value is in range [-1, 1].

Return the correlation coefficient between seq1 and seq2, which should be of equal size. Value is in range [-1, 1]. 
raw docstring

pow10clj/s

(pow10 i)

powTclj/s


prime-factorsclj/s

(prime-factors n)

Prime factors of n. Can include duplicates

Prime factors of n. Can include duplicates
raw docstring

prime?clj/s

(prime? n)

primesclj/s


r2dclj/s

(r2d r)

Convert radians to degrees

Convert radians to degrees
raw docstring

rescaleclj/s

(rescale val from-lower from-upper to-lower to-upper)

Val is a number from interval [from-lower, from-upper], scale it to [to-lower, to-upper]

Val is a number from interval [from-lower, from-upper], scale it to [to-lower, to-upper]
raw docstring

score-bclj/s

(score-b keyfn seq)

Return a list of [elt score] pairs, in descending score order.

Return a list of [elt score] pairs, in descending score order.
raw docstring

squareTclj/s


standard-deviationclj/s

(standard-deviation seq)

Return standard deviation of the elements of seq

Return standard deviation of the elements of `seq`
raw docstring

standard-deviation-sampleclj/s

(standard-deviation-sample seq)

Return standard deviation with Bessel correction of the elements of seq

Return standard deviation with Bessel correction of the elements of `seq`
raw docstring

Tclj/s


tensorizeclj/s

(tensorize f)

Generate a tensorized version of any f

Generate a tensorized version of any f
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries