(add-deltas field delta-field ms)(add-field field f ms)(compare-ms ms1 ms2 index)(cond-prob ms pl pr)(ms-describe ms)(ms-fields ms)(ms-filter ms field pred)Filter ms based on field and pred
Filter ms based on field and pred
(ms-find ms re)Find values that match re, return seq of [k v rec]
Find values that match re, return seq of [k v rec]
(ms-join ms1 ms2 f1 f2)(ms-range field ms)Returns [min, max, count-distinct] using generic comapre
Returns [min, max, count-distinct] using generic comapre
(rename-field ms from to)(reshape-fat mapseq id-col prop-col val-col)Reshape a mapseq from skinny to fat
Reshape a mapseq from skinny to fat
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |